@@ -14,21 +14,23 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
+from typing import Tuple,Union,List
+from time import sleep
+
 from nonebot.matcher import Matcher
 from nonebot.typing import T_State
 from nonebot.params import CommandArg,ArgPlainText,RegexGroup,Arg,RawCommand,CommandStart
+from nonebot import get_driver, require
+from nonebot.plugin import PluginMetadata
 
-from typing import Tuple,Union,List
-from time import sleep
-import asyncio
 
 from .config import *
 from .utils import *
 from .command import *
 from .l4d2_image.steam import url_to_byte,url_to_byte_name
-from nonebot.plugin import PluginMetadata
+
 from .l4d2_data import sq_L4D2
-from nonebot import get_driver, require
+
 from .l4d2_image.vtfs import img_to_vtf
 from .l4d2_queries.ohter import load_josn
 from .l4d2_queries.qqgroup import write_json
@@ -36,13 +38,14 @@ from .l4d2_file import updown_l4d2_vpk,all_zip_to_one
 
 from .txt_to_img import mode_txt_to_img
 # from .l4d2_server import RCONClient
-# from .l4d2_web import web,webUI
 scheduler = require("nonebot_plugin_apscheduler").scheduler
 
+from .l4d2_web import web,webUI
+
 driver = get_driver()
 
 
-__version__ = "0.4.1"
+__version__ = "0.4.3"
 __plugin_meta__ = PluginMetadata(
     name="求生之路小助手",
     description='群内对有关求生之路的查询和操作',
@@ -60,46 +63,38 @@ __plugin_meta__ = PluginMetadata(
 @up.handle()
 async def _(matcher:Matcher,event: NoticeEvent):
     args = event.dict()
-    map_path = Path(l4_file[CHECK_FILE],vpk_path)
     if args['notice_type'] != 'offline_file':
         matcher.set_arg('txt',args)
-    else:
+        return
+    l4_file_path = l4_file[CHECK_FILE]
+    map_path = Path(l4_file_path, vpk_path)
     # 检查下载路径是否存在
-    # logger.info('检查下载路径是否存在')
-        l4_file_path = l4_file[CHECK_FILE]
-        # 检查下载路径是否存在
-        logger.info(l4_file_path)
-        if not Path(l4_file_path).exists():
-            await up.finish("你填写的路径不存在辣")
-        if not Path(map_path).exists():
-            await up.finish("这个路径并不是求生服务器的路径，请再看看罢")
-            # args = event.dict()
-        # if args['notice_type'] != 'offline_file':  # 群聊值响应超管
-        #     return
-        url = args['file']['url']
-        name: str = args['file']['name']
-        # user_id = txt['user_id']
-        # 如果不符合格式则忽略
-        await up.send('已收到文件，开始下载')
-        sleep(1)   # 等待一秒防止因为文件名获取出现BUG
-        vpk_files = await updown_l4d2_vpk(map_path,name,url)
-        if vpk_files:
-            logger.info('检查到新增文件')
-            mes = "解压成功，新增以下几个vpk文件"
-        else:
-            mes = "你可能上传了相同的文件，或者解压失败了捏"
-                
-        await up.finish(mes_list(mes,vpk_files))
+    if not Path(l4_file_path).exists():
+        await matcher.finish("你填写的路径不存在辣")
+        return
+    if not Path(map_path).exists():
+        await matcher.finish("这个路径并不是求生服务器的路径，请再看看罢")
+        return
+    url = args['file']['url']
+    name: str = args['file']['name']
+    # 如果不符合格式则忽略
+    await up.send('已收到文件，开始下载')
+    sleep(1)   # 等待一秒防止因为文件名获取出现BUG
+    vpk_files = await updown_l4d2_vpk(map_path,name,url)
+    if vpk_files:
+        mes = "解压成功，新增以下几个vpk文件"
+        await matcher.finish(mes_list(mes,vpk_files))
+    else:
+        await matcher.finish("你可能上传了相同的文件，或者解压失败了捏")
 
 
-@up.got("is_sure",prompt="请选择上传位置（输入阿拉伯数字)")    
+
+@up.got("is_sure", prompt="请选择上传位置（输入阿拉伯数字)")    
 async def _(matcher: Matcher):
     args = matcher.get_arg('txt')
-    map_path = Path(l4_file[CHECK_FILE],vpk_path)
-    sleep(1)
     if not args:
         await matcher.finish('获取文件出错辣，再试一次吧')
-    # args = txt.dict()
+
     is_sure = str(matcher.get_arg('is_sure')).strip()
     if not is_sure.isdigit():
         await matcher.finish('已取消上传')
@@ -108,35 +103,38 @@ async def _(matcher: Matcher):
     if is_sure > file_number or is_sure <= 0:
         await matcher.finish('没有该序号')
     l4_file_path = l4_file[is_sure - 1]
-    
+
+    map_path = Path(l4_file_path, vpk_path)
+
     # 检查下载路径是否存在
-    logger.info(l4_file_path)
     if not Path(l4_file_path).exists():
-        await up.finish("你填写的路径不存在辣")
-    if not Path(map_path).exists():
-        await up.finish("这个路径并不是求生服务器的路径，请再看看罢")
-    # args = event.dict()
-    # if args['notice_type'] != 'offline_file':  # 群聊值响应超管
+        await matcher.finish("你填写的路径不存在辣")
+    if not map_path.exists():
+        await matcher.finish("这个路径并不是求生服务器的路径，请再看看罢")
+
     url = args['file']['url']
-    name: str = args['file']['name']
-    # user_id = args['user_id']
+    name = args['file']['name']
     # 如果不符合格式则忽略
     if not name.endswith(file_format):
         return
-    await up.send('已收到文件，开始下载')
+
+    await matcher.send('已收到文件，开始下载')
     sleep(1)   # 等待一秒防止因为文件名获取出现BUG
-    vpk_files = await updown_l4d2_vpk(Path(l4_file_path,vpk_path),name,url)
+    vpk_files = await updown_l4d2_vpk(map_path, name, url)
+
     if vpk_files:
         logger.info('检查到新增文件')
         mes = "解压成功，新增以下几个vpk文件"
-    elif vpk_files == None:
-        await up.finish('文件错误')
+    elif vpk_files is None:
+        await matcher.finish('文件错误')
     else:
         mes = "你可能上传了相同的文件，或者解压失败了捏"
-    await up.finish(mes_list(mes,vpk_files))
+
+    await matcher.finish(mes_list(mes, vpk_files))
+
     
 @find_vpk.handle()
-async def _(bot:Bot,event: MessageEvent):
+async def _(bot:Bot,event: MessageEvent,matcher: Matcher):
     name_vpk = []
     map_path = Path(l4_file[CHECK_FILE],vpk_path)
     name_vpk = get_vpk(name_vpk,map_path)
@@ -145,7 +143,7 @@ async def _(bot:Bot,event: MessageEvent):
     msg = ''
     msg = mes_list(msg,name_vpk).replace(" ","")
     
-    await find_vpk.finish(mode_txt_to_img(mes,msg))
+    await matcher.finish(mode_txt_to_img(mes,msg))
 
 @del_vpk.handle()
 async def _(matcher:Matcher,args:Message = CommandArg()):
@@ -154,13 +152,13 @@ async def _(matcher:Matcher,args:Message = CommandArg()):
         matcher.set_arg("num",args)
 
 @del_vpk.got("num",prompt="你要删除第几个序号的地图(阿拉伯数字)")
-async def _(tag:int = ArgPlainText("num")):
+async def _(matcher: Matcher,tag:int = ArgPlainText("num")):
     map_path = Path(l4_file[CHECK_FILE],vpk_path)
     vpk_name = del_map(tag,map_path)
-    await del_vpk.finish('已删除地图：' + vpk_name)
+    await matcher.finish('已删除地图：' + vpk_name)
     
 @rename_vpk.handle()
-async def _(matched: Tuple[int,str, str] = RegexGroup(),):
+async def _(matcher:Matcher,matched: Tuple[int,str, str] = RegexGroup(),):
     num,useless,rename = matched
     map_path = Path(l4_file[CHECK_FILE],vpk_path)
     logger.info('检查是否名字是.vpk后缀')
@@ -170,12 +168,12 @@ async def _(matched: Tuple[int,str, str] = RegexGroup(),):
     try:
         map_name = rename_map(num,rename,map_path)
         if map_name:
-            await rename_vpk.finish('改名成功\n原名:'+ map_name +'\n新名称:' + rename)
+            await matcher.finish('改名成功\n原名:'+ map_name +'\n新名称:' + rename)
     except ValueError:
-        await rename_vpk.finish('参数错误,请输入格式如【求生地图 5 改名 map.vpk】,或者输入【求生地图】获取全部名称')
+        await matcher.finish('参数错误,请输入格式如【求生地图 5 改名 map.vpk】,或者输入【求生地图】获取全部名称')
         
 @anne_player.handle()
-async def _(event:MessageEvent,args:Message = CommandArg()):
+async def _(matcher:Matcher,event:MessageEvent,args:Message = CommandArg()):
     name = args.extract_plain_text()
     name = name.strip()
     at = await get_message_at(event.json())
@@ -185,25 +183,25 @@ async def _(event:MessageEvent,args:Message = CommandArg()):
     # 没有参数则从db里找数据
     msg = await search_anne(name,usr_id)
     if type(msg)==str:
-        await anne_player.finish(msg)
+        await matcher.finish(msg)
     else:
-        await anne_player.finish(MessageSegment.image(msg)) 
+        await matcher.finish(MessageSegment.image(msg)) 
     
 @anne_bind.handle()
-async def _(event:MessageEvent,args:Message = CommandArg()):
+async def _(matcher:Matcher,event:MessageEvent,args:Message = CommandArg()):
     tag = args.extract_plain_text()
     tag = tag.strip()
     if tag=="" or tag.isspace():
-        await anne_bind.finish("虚空绑定?")
+        await matcher.finish("虚空绑定?")
     usr_id = str(event.user_id)
     nickname = event.sender.card or event.sender.nickname
     msg = await bind_steam(usr_id,tag,nickname)
-    await anne_bind.finish(msg)
+    await matcher.finish(msg)
 
 @del_bind.handle()
-async def _(event:MessageEvent):
+async def _(matcher:Matcher,event:MessageEvent):
     usr_id = event.user_id
-    await del_bind.finish(name_exist(usr_id))
+    await matcher.finish(name_exist(usr_id))
 
 @rcon_to_server.handle()
 async def _(matcher:Matcher,args:Message = CommandArg()):
@@ -212,13 +210,13 @@ async def _(matcher:Matcher,args:Message = CommandArg()):
         matcher.set_arg("command",args)
 
 @rcon_to_server.got("command",prompt="请输入向服务器发送的指令")
-async def _(tag:str = ArgPlainText("command")):
+async def _(matcher:Matcher,tag:str = ArgPlainText("command")):
     tag = tag.strip()
     msg = await command_server(tag)
     if l4_image:
-        await rcon_to_server.finish(mode_txt_to_img('服务器返回',msg))
+        await matcher.finish(mode_txt_to_img('服务器返回',msg))
     else:
-        await rcon_to_server.finish(msg,reply_message = True)
+        await matcher.finish(msg,reply_message = True)
         
 
 # 连续rcon连接
@@ -241,20 +239,20 @@ async def _(tag:str = ArgPlainText("command")):
         
         
 @check_path.handle()
-async def _(args:Message = CommandArg()):
+async def _(matcher:Matcher,args:Message = CommandArg()):
     global CHECK_FILE
     msg = args.extract_plain_text()
     if msg.startswith('切换'):
         msg_number = int(''.join(msg.replace('切换', ' ').split()))
         if msg_number > len(l4_file) or msg_number < 0:
-            await check_path.send('没有这个序号的路径呐')
+            await matcher.send('没有这个序号的路径呐')
         else:
             CHECK_FILE = msg_number - 1
             now_path = l4_file[CHECK_FILE]
-            await check_path.send(f'已经切换路径为\n{str(CHECK_FILE+1)}、{now_path}')
+            await matcher.send(f'已经切换路径为\n{str(CHECK_FILE+1)}、{now_path}')
     else: 
         now_path = l4_file[CHECK_FILE]
-        await check_path.send(f'当前的路径为\n{str(CHECK_FILE+1)}、{now_path}')
+        await matcher.send(f'当前的路径为\n{str(CHECK_FILE+1)}、{now_path}')
         
         
 @queries.handle()
@@ -264,41 +262,41 @@ async def _(matcher:Matcher,args:Message = CommandArg()):
         matcher.set_arg("ip",args)
 
 @queries.got("ip",prompt="请输入ip,格式如中括号内【127.0.0.1】【114.51.49.19:1810】")
-async def _(tag:str = ArgPlainText("ip")):
+async def _(matcher:Matcher,tag:str = ArgPlainText("ip")):
     ip = split_maohao(tag)
     msg = await queries_server(ip)
-    await queries.finish(msg)
+    await matcher.finish(msg)
     
 
 @add_queries.handle()
-async def _(event:GroupMessageEvent,args:Message = CommandArg()):
+async def _(matcher:Matcher,event:GroupMessageEvent,args:Message = CommandArg()):
     msg = args.extract_plain_text()
     if len(msg)==0:
-        await add_queries.finish('请在该指令后加入参数，例如【114.51.49.19:1810】')
+        await matcher.finish('请在该指令后加入参数，例如【114.51.49.19:1810】')
     [host,port] = split_maohao(msg)
     group_id = event.group_id
     msg = await add_ip(group_id,host,port)
-    await add_queries.finish(msg)
+    await matcher.finish(msg)
 
 @del_queries.handle()
 async def _(event:GroupMessageEvent,matcher:Matcher,args:Message = CommandArg()):
     msg = args.extract_plain_text()
     if not msg.isdigit():
-        await del_queries.finish('请输入正确的序号数字')
+        await matcher.finish('请输入正确的序号数字')
     group_id = event.group_id
     msg = await del_ip(group_id,msg)
-    await del_queries.finish(msg)
+    await matcher.finish(msg)
    
 @show_queries.handle()
-async def _(event:GroupMessageEvent):
+async def _(matcher:Matcher,event:GroupMessageEvent):
     group_id = event.group_id
     msg = await show_ip(group_id)
     if not msg:
-        await show_queries.finish("当前没有启动的服务器捏")
+        await matcher.finish("当前没有启动的服务器捏")
     if type(msg) == str:
-        await show_queries.finish(msg)
+        await matcher.finish(msg)
     else:
-        await show_queries.finish(MessageSegment.image(msg))
+        await matcher.finish(MessageSegment.image(msg))
 
 @join_server.handle()
 async def _(args:Message = CommandArg()):
@@ -314,10 +312,10 @@ async def _(matcher:Matcher,args:Message = CommandArg()):
         matcher.set_arg("ip",args)
     
 @up_workshop.got("ip",prompt="请输入创意工坊网址或者物品id")
-async def _(state:T_State,tag:str = ArgPlainText("ip")):
+async def _(matcher:Matcher,state:T_State,tag:str = ArgPlainText("ip")):
     msg = await workshop_msg(tag)
     if not msg:
-        await up_workshop.finish('没有这个物品捏')
+        await matcher.finish('没有这个物品捏')
     elif type(msg) == dict:
         pic = await url_to_byte(msg['图片地址'])
         message = ''
@@ -349,7 +347,7 @@ async def _(matcher: Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
             logger.info('开始上传')
             data_file = await url_to_byte(data_dict['下载地址'])
             file_name = data_dict['名字']+ '.vpk'
-            await up_workshop.send('获取地址成功，尝试上传')
+            await matcher.send('获取地址成功，尝试上传')
             await upload_file(bot, event, data_file, file_name)
         else:
             logger.info('开始上传')
@@ -359,21 +357,21 @@ async def _(matcher: Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
             file_name = data_one['名字']+ '.vpk'
             await upload_file(bot, event, data_file, file_name)
     else:
-        await up_workshop.finish('已取消上传')
+        await matcher.finish('已取消上传')
     
 
 
 @updata.handle()
-async def _(args:Message = CommandArg()):
+async def _(matcher:Matcher,args:Message = CommandArg()):
     """更新"""
     msg = args.extract_plain_text()
     if not msg:
         load_josn()
         reload_ip()
-        await updata.finish('已更新缓存数据')
+        await matcher.finish('已更新缓存数据')
     else:
         message = await write_json(msg)
-        await updata.finish(message)
+        await matcher.finish(message)
   
 
             
@@ -381,7 +379,7 @@ async def _(args:Message = CommandArg()):
 async def _(matcher:Matcher,state:T_State,args:Message = CommandArg()):
     msg:str = args.extract_plain_text()
     if msg not in ['拉伸','填充','覆盖','']:
-        await vtf_make.finish('错误的图片处理方式')
+        await matcher.finish('错误的图片处理方式')
     if msg == '':
         msg = '拉伸'
     state['way'] = msg
@@ -404,7 +402,7 @@ async def _(bot:Bot,event:MessageEvent,state:T_State,tag = Arg("image")):
 
 
 @smx_file.handle()
-async def _():
+async def _(matcher:Matcher,):
     smx_path = Path(l4_file[CHECK_FILE],"left4dead2/addons/sourcemod/plugins")
     smx_list = []
     name_smx = get_vpk(smx_list,smx_path,file_=".smx")
@@ -412,23 +410,23 @@ async def _():
     mes = "当前服务器下有以下smx文件"
     msg = ''
     msg = mes_list(msg,name_smx).replace(" ","")
-    await find_vpk.finish(mode_txt_to_img(mes,msg))
+    await matcher.finish(mode_txt_to_img(mes,msg))
     
 @search_api.handle()
-async def _(state:T_State,event:GroupMessageEvent,args:Message = CommandArg()):
+async def _(matcher:Matcher,state:T_State,event:GroupMessageEvent,args:Message = CommandArg()):
     msg:str = args.extract_plain_text()
     # if msg.startswith('代码'):
         # 建图代码返回三方图信息
-    data = await seach_map(msg,l4_qq,l4_key)
+    data = seach_map(msg,l4_qq,l4_key)
     # else:
     if type(data) == str:
-        await search_api.finish(data)
+        await matcher.finish(data)
     else:
         state['maps'] = data
-        await search_api.send(await map_dict_to_str(data))
+        await matcher.send(await map_dict_to_str(data))
         
 @search_api.got("is_sure",prompt='如果需要上传，请发送 "yes"')    
-async def _(bot:Bot,event:GroupMessageEvent,state:T_State):
+async def _(matcher:Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
     is_sure = str(state["is_sure"])
     if is_sure == 'yes':
         data_dict:dict = state['maps'][0]
@@ -439,7 +437,7 @@ async def _(bot:Bot,event:GroupMessageEvent,state:T_State):
             else:
                 data_file,file_name = await url_to_byte_name(data_dict['url'])
             if data_file:
-                await search_api.send('获取地址成功，尝试上传')
+                await matcher.send('获取地址成功，尝试上传')
                 await upload_file(bot, event, data_file, file_name)
             else:
                 await search_api.send('出错了，原因是下载链接不存在')
@@ -450,91 +448,9 @@ async def _(bot:Bot,event:GroupMessageEvent,state:T_State):
                 await all_zip_to_one
                 await upload_file(bot, event, data_file, file_name)
     else:
-        await search_api.finish('已取消上传')
+        await matcher.finish('已取消上传')
         
 
-@driver.on_startup
-async def _():
-    global ALL_HOST
-    global ANNE_IP
-    if l4_tag == None:
-        pass
-    else:
-        ALL_HOST.update(await seach_map(l4_tag,l4_qq,l4_key,'ip'))
-        def count_ips(ip_dict:dict):
-            for key, value in ip_dict.items():
-                if key == 'error_':
-                    continue
-                count = len(value)
-                logger.info(f'已加载：{key} | {count}个')
-                if key == '云':
-                    ANNE_IP = {key:value}
-        count_ips(ALL_HOST)
-        ip_anne_list=[] 
-        try:
-            ips = ALL_HOST['云']
-            ip_anne_list = []
-            for one_ip in ips:
-                host,port = split_maohao(one_ip['ip'])
-                ip_anne_list.append((one_ip['id'],host,port))
-        except KeyError:
-            pass
-    get_ip = on_command('anne',aliases=server_key(),priority=80,block=True)
-    @get_ip.handle()
-    async def _(start:str = CommandStart(),command: str = RawCommand(),args:Message = CommandArg(),):
-        if start:
-            command.replace(start,'')
-        if command == 'anne':
-            command = '云'
-        msg:str = args.extract_plain_text()
-        if not msg:
-            # 以图片输出全部当前
-            this_ips = ALL_HOST[command]
-            ip_list = []
-            for one_ip in this_ips:
-                host,port = split_maohao(one_ip['ip'])
-                ip_list.append((one_ip['id'],host,port))
-            img = await qq_ip_queries_pic(ip_list)
-            if img:
-                await get_ip.finish(MessageSegment.image(img)) 
-            else:
-                await get_ip.finish("服务器无响应")
-        else:
-            if not msg[0].isdigit():
-                if any(mode in msg for mode in gamemode_list):
-                    pass
-                else:
-                    return
-            message = await json_server_to_tag_dict(command,msg)
-            if len(message) == 0:
-                # 关键词不匹配，忽略
-                return
-            ip = str(message['ip'])
-            logger.info(ip)
-            try:
-                msg= await get_anne_server_ip(ip)
-                await get_ip.finish(msg)
-            except (OSError,asyncio.exceptions.TimeoutError):
-                await get_ip.finish('服务器无响应')
-                
-    @tan_jian.handle()
-    async def _(event:MessageEvent):
-        await tan_jian.send('正在寻找牢房...')
-        msg = await get_tan_jian(ip_anne_list,1)
-        await tan_jian.finish(msg)  
-        
-    @prison.handle()
-    async def _(event:MessageEvent):
-        msg = await get_tan_jian(ip_anne_list,2)
-        await tan_jian.finish(msg)
-
-    @open_prison.handle()
-    async def _(event:MessageEvent):
-
-        msg = await get_tan_jian(ip_anne_list,3)
-        await tan_jian.finish(msg)
-    
-            
 @driver.on_shutdown
 async def close_db():
     """关闭数据库"""
